@@ -1,6 +1,7 @@
 package Pcore::App::Selenium;
 
 use Pcore -class;
+use Pcore::Selenium;
 
 extends qw[Pcore::App::Alien];
 
@@ -30,12 +31,16 @@ our $CFG = {
 };
 
 # CLI
-sub cli_name ($self) {
-    return 'selenium';
-}
+around CLI => sub ( $orig, $self ) {
+    my $cli = $self->$orig;
+
+    $cli->{name} = 'selenium';
+
+    return $cli;
+};
 
 sub _build_selenium_ver ($self) {
-    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->{CFG}->{SELENIUM}->{SELENIUM_VER};
+    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->get_dist('pcore-selenium')->cfg->{SELENIUM}->{SELENIUM_VER};
 }
 
 sub _build_selenium_uri ($self) {
@@ -45,7 +50,7 @@ sub _build_selenium_uri ($self) {
 }
 
 sub _build_ff_ver ($self) {
-    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->{CFG}->{SELENIUM}->{FF_VER};
+    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->get_dist('pcore-selenium')->cfg->{SELENIUM}->{FF_VER};
 }
 
 sub _build_alien_bin_path ($self) {
@@ -124,7 +129,7 @@ sub _build_ff_extensions ($self) {
             $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->{$ext},
             buf_size    => 1,
             on_progress => 1,
-            blocking    => $cv,
+            cv          => $cv,
             on_finish   => sub ($res) {
                 if ( $res->status == 200 ) {
                     my $zip = Archive::Zip->new;
@@ -221,9 +226,9 @@ sub alien_proc ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 120                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 125                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 139                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 144                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
